@@ -4,6 +4,7 @@ package chezmoi
 
 import (
 	"io/fs"
+	"os"
 
 	"golang.org/x/sys/unix"
 )
@@ -26,6 +27,11 @@ func IsExecutable(fileInfo fs.FileInfo) bool {
 	return fileInfo.Mode().Perm()&0o111 != 0
 }
 
+// UserHomeDir on UNIX returns the value of os.UserHomeDir.
+func UserHomeDir() (string, error) {
+	return os.UserHomeDir()
+}
+
 // isPrivate returns if fileInfo is private.
 func isPrivate(fileInfo fs.FileInfo) bool {
 	return fileInfo.Mode().Perm()&0o77 == 0
