@@ -20,35 +20,37 @@ func newSourceStateTreeNode() *sourceStateEntryTreeNode {
 	return &sourceStateEntryTreeNode{}
 }
 
-// Get returns the SourceStateEntry at relPath.
-func (n *sourceStateEntryTreeNode) Get(relPath RelPath) SourceStateEntry {
-	node := n.GetNode(relPath)
-	if node == nil {
+// get returns the SourceStateEntry at relPath.
+func (n *sourceStateEntryTreeNode) get(relPath RelPath) SourceStateEntry {
+	nodes := n.getNodes(relPath)
+	if nodes == nil {
 		return nil
 	}
-	return node.sourceStateEntry
+	return nodes[len(nodes)-1].sourceStateEntry
 }
 
-// GetNode returns the SourceStateTreeNode at relPath.
-func (n *sourceStateEntryTreeNode) GetNode(targetRelPath RelPath) *sourceStateEntryTreeNode {
+// getNodes returns the sourceStateEntryTreeNodes to reach targetRelPath.
+func (n *sourceStateEntryTreeNode) getNodes(targetRelPath RelPath) []*sourceStateEntryTreeNode {
 	if targetRelPath.Empty() {
-		return n
+		return []*sourceStateEntryTreeNode{n}
 	}
 
-	node := n
-	for _, childRelPath := range targetRelPath.SplitAll() {
-		if childNode, ok := node.children[childRelPath]; ok {
-			node = childNode
+	targetRelPathComponents := targetRelPath.SplitAll()
+	nodes := make([]*sourceStateEntryTreeNode, 0, len(targetRelPathComponents))
+	nodes = append(nodes, n)
+	for _, childRelPath := range targetRelPathComponents {
+		if childNode, ok := nodes[len(nodes)-1].children[childRelPath]; ok {
+			nodes = append(nodes, childNode)
 		} else {
 			return nil
 		}
 	}
-	return node
+	return nodes
 }
 
-// ForEach calls f for each SourceStateEntry in the tree.
-func (n *sourceStateEntryTreeNode) ForEach(targetRelPath RelPath, f func(RelPath, SourceStateEntry) error) error {
-	return n.ForEachNode(targetRelPath, func(targetRelPath RelPath, node *sourceStateEntryTreeNode) error {
+// forEach calls f for each SourceStateEntry in the tree.
+func (n *sourceStateEntryTreeNode) forEach(targetRelPath RelPath, f func(RelPath, SourceStateEntry) error) error {
+	return n.forEachNode(targetRelPath, func(targetRelPath RelPath, node *sourceStateEntryTreeNode) error {
 		if node.sourceStateEntry == nil {
 			return nil
 		}
@@ -56,8 +58,8 @@ func (n *sourceStateEntryTreeNode) ForEach(targetRelPath RelPath, f func(RelPath
 	})
 }
 
-// ForEachNode calls f for each node in the tree.
-func (n *sourceStateEntryTreeNode) ForEachNode(targetRelPath RelPath, f func(RelPath, *sourceStateEntryTreeNode) error) error {
+// forEachNode calls f for each node in the tree.
+func (n *sourceStateEntryTreeNode) forEachNode(targetRelPath RelPath, f func(RelPath, *sourceStateEntryTreeNode) error) error {
 	switch err := f(targetRelPath, n); {
 	case errors.Is(err, fs.SkipDir):
 		return nil
@@ -69,7 +71,7 @@ func (n *sourceStateEntryTreeNode) ForEachNode(targetRelPath RelPath, f func(Rel
 	sort.Sort(childrenByRelPath)
 	for _, childRelPath := range childrenByRelPath {
 		child := n.children[childRelPath]
-		if err := child.ForEachNode(targetRelPath.Join(childRelPath), f); err != nil {
+		if err := child.forEachNode(targetRelPath.Join(childRelPath), f); err != nil {
 			return err
 		}
 	}
@@ -77,19 +79,19 @@ func (n *sourceStateEntryTreeNode) ForEachNode(targetRelPath RelPath, f func(Rel
 	return nil
 }
 
-// Map returns a map of relPaths to SourceStateEntries.
-func (n *sourceStateEntryTreeNode) Map() map[RelPath]SourceStateEntry {
+// getMap returns a map of relPaths to SourceStateEntries.
+func (n *sourceStateEntryTreeNode) getMap() map[RelPath]SourceStateEntry {
 	m := make(map[RelPath]SourceStateEntry)
-	_ = n.ForEach(EmptyRelPath, func(relPath RelPath, sourceStateEntry SourceStateEntry) error {
+	_ = n.forEach(EmptyRelPath, func(relPath RelPath, sourceStateEntry SourceStateEntry) error {
 		m[relPath] = sourceStateEntry
 		return nil
 	})
 	return m
 }
 
-// MkdirAll creates SourceStateDirs for all components of targetRelPath if they
+// mkdirAll creates SourceStateDirs for all components of targetRelPath if they
 // do not already exist and returns the SourceStateDir of relPath.
-func (n *sourceStateEntryTreeNode) MkdirAll(
+func (n *sourceStateEntryTreeNode) mkdirAll(
 	targetRelPath RelPath,
 	origin SourceStateOrigin,
 	umask fs.FileMode,
@@ -142,8 +144,8 @@ func (n *sourceStateEntryTreeNode) MkdirAll(
 	return sourceStateDir, nil
 }
 
-// Set sets the SourceStateEntry at relPath to sourceStateEntry.
-func (n *sourceStateEntryTreeNode) Set(targetRelPath RelPath, sourceStateEntry SourceStateEntry) {
+// set sets the SourceStateEntry at relPath to sourceStateEntry.
+func (n *sourceStateEntryTreeNode) set(targetRelPath RelPath, sourceStateEntry SourceStateEntry) {
 	if targetRelPath.Empty() {
 		n.sourceStateEntry = sourceStateEntry
 		return
