@@ -398,6 +398,7 @@ func newConfig(options ...configOption) (*Config, error) {
 	// Override sprig template functions. Delete them from the template function
 	// map first to avoid a duplicate function panic.
 	delete(c.templateFuncs, "fromJson")
+	delete(c.templateFuncs, "splitList")
 	delete(c.templateFuncs, "toPrettyJson")
 
 	// The completion template function is added in persistentPreRunRootE as
@@ -477,6 +478,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"secret":                   c.secretTemplateFunc,
 		"secretJSON":               c.secretJSONTemplateFunc,
 		"setValueAtPath":           c.setValueAtPathTemplateFunc,
+		"splitList":                c.splitListTemplateFunc,
 		"stat":                     c.statTemplateFunc,
 		"toIni":                    c.toIniTemplateFunc,
 		"toPrettyJson":             c.toPrettyJsonTemplateFunc,
@@ -2783,8 +2785,16 @@ func (f *ConfigFile) toMap() map[string]any {
 		configFile.Diff.Pager = ""
 	}
 
+	// This is a horrible hack. We want the returned map to contain only simple
+	// types because they are used with masterminds/sprig template functions
+	// which don't accept fmt.Stringers in place of strings. As a work-around,
+	// round-trip via JSON.
+	data, err := json.Marshal(configFile)
+	if err != nil {
+		return nil
+	}
 	var result map[string]any
-	if err := mapstructure.Decode(configFile, &result); err != nil {
+	if err := json.Unmarshal(data, &result); err != nil {
 		panic(err)
 	}
 	return result
