@@ -5,10 +5,9 @@ import (
 	"encoding/json"
 	"os"
 	"os/exec"
+	"slices"
 	"strings"
 
-	"golang.org/x/exp/slices"
-
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
@@ -49,7 +48,7 @@ func (c *Config) secretOutput(args []string) ([]byte, error) {
 	cmd := exec.Command(c.Secret.Command, args...) //nolint:gosec
 	cmd.Stdin = os.Stdin
 	cmd.Stderr = os.Stderr
-	output, err := chezmoilog.LogCmdOutput(cmd)
+	output, err := chezmoilog.LogCmdOutput(c.logger, cmd)
 	if err != nil {
 		return nil, newCmdOutputError(cmd, output, err)
 	}
